# Copyright (c) 2019 Mycroft AI, Inc.
#
# This file is part of Mycroft Skills Manager
# (see https://github.com/MatthewScholefield/mycroft-light).
#
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.
from pako.config_loader import recursive_merge, load_package_managers_overrides

__package_managers = {
    'eopkg': {
        'sudo': True,
        'update': 'ur',
        'install': 'it -y',
        'formats': {
            'exe': ['{}', '{}-utils', '{}-bin'],
            'lib': ['{}', 'lib{}'],
            'lib-dev': ['{}-devel', 'lib{}-devel'],
            'lib-debug': ['{}-dbginfo', 'lib{}-dbginfo'],
        }
    },
    'apt-get': {
        'sudo': True,
        'update': 'update',
        'install': 'install',
        'formats': {
            'exe': ['{}', '{}-utils'],
            'lib': ['lib{}', '{}'],
            'lib-dev': ['lib{}-dev', '{}-dev'],
            'lib-debug': ['lib{}-dbg', '{}-dbg']
        }
    }
}


def get_package_manager_names():
    return list(__package_managers)


def load_package_manager_data():
    return dict(recursive_merge(__package_managers, load_package_managers_overrides()))
